---
sidebar_position: 10
sidebar_label: "3-state exchange kinetic model"
---

# 3-state exchange kinetic model

:::note Files

You can get
[the example files from the GitHub ChemEx page](https://github.com/gbouvignies/chemex/tree/master/examples/Experiments/DCEST_15N_3States).

The `README.txt` file contains explanations about the different fitting schemes

:::

This example demonstrates the study of systems with 3-state exchange using
ChemEx. For systems with 3-state exchange, two separate minor dips may show up
in CEST profiles. However, it is often difficult to identify the correct
exchange model without additional information. In this example double-resonance
D-CEST experiments have been carried out to distinguish between the two possible
exchange models.[^1]

[^1]:
    P. Vallurupalli, V. K. Tiwari, and S. Ghosh. A Double-Resonance CEST
    Experiment To Study Multistate Protein Conformational Exchange: An
    Application to Protein Folding. _J. Phys. Chem. Lett._ **10**, 3051-3056
    (2019). https://doi.org/10.1021/acs.jpclett.9b00985
